@@ -3,24 +3,16 @@
 from argparse import ArgumentParser, Namespace
 from logging import INFO, basicConfig, getLogger
 from pathlib import Path
-from socket import timeout
-from sys import exit    # pylint: disable=W0622
 
 from rcon.errorhandler import ErrorHandler
-from rcon.exceptions import RequestIdMismatch
-from rcon.rconclt import get_credentials
 from rcon.readline import CommandHistory
-from rcon.config import CONFIG_FILE, LOG_FORMAT
+from rcon.config import CONFIG_FILES, LOG_FORMAT, from_args
 from rcon.console import PROMPT, rconcmd
 
 
 __all__ = ['get_args', 'main']
 
-ERRORS = (
-    (ConnectionRefusedError, 'Connection refused.', 3),
-    ((TimeoutError, timeout), 'Connection timeout.', 4),
-    (RequestIdMismatch, 'Unexpected request ID mismatch.', 5)
-)
+
 LOGGER = getLogger('rconshell')
 
 
@@ -30,7 +22,7 @@ def get_args() -> Namespace:
     parser = ArgumentParser(description='An interactive RCON shell.')
     parser.add_argument('server', nargs='?', help='the server to connect to')
     parser.add_argument('-c', '--config', type=Path, metavar='file',
-                        default=CONFIG_FILE, help='the configuration file')
+                        default=CONFIG_FILES, help='the configuration file')
     parser.add_argument('-p', '--prompt', default=PROMPT, metavar='PS1',
                         help='the shell prompt')
     return parser.parse_args()
@@ -43,12 +35,10 @@ def main() -> None:
     basicConfig(level=INFO, format=LOG_FORMAT)
 
     if args.server:
-        host, port, passwd = get_credentials(args)
+        host, port, passwd = from_args(args)
     else:
         host = port = passwd = None
 
-    with ErrorHandler(ERRORS, LOGGER):
+    with ErrorHandler(LOGGER):
         with CommandHistory(LOGGER):
-            returncode = rconcmd(host, port, passwd, prompt=args.prompt)
-
-    exit(returncode)
+            rconcmd(host, port, passwd, prompt=args.prompt)
